@@ -27,6 +27,14 @@ export class ServerManager extends ReactWidget {
     return (
       <div>
         <h4>TigerGraph Database Server</h4>
+        <p>
+          <a
+            href="https://docs.tigergraph.com/ml-workbench/current/overview/"
+            target="_blank"
+          >
+            Help
+          </a>
+        </p>
         <ServerIndex
           jupyterApp={this._jupyterApp}
           settings={this._jupyterSettings}
