@@ -10,27 +10,27 @@ const tutorialIndex: { [key: string]: tutorialType } = {
   basics: {
     '0_data_ingestion': {
       label: 'Data Ingestion',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/basics/0_data_ingestion.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/basics/0_data_ingestion.ipynb'
     },
     '1_data_processing': {
       label: 'Data Processing',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/basics/1_data_processing.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/basics/1_data_processing.ipynb'
     },
     '2_dataloaders': {
       label: 'Data Loaders',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/basics/2_dataloaders.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/basics/2_dataloaders.ipynb'
     },
     '3.1_graph_convolutional_network': {
       label: 'Graph Convolutional Network',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/gnn_pyg/graph_convolutional_network.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/gnn_pyg/graph_convolutional_network.ipynb'
     },
     '3.2_graphSAGE': {
       label: 'GraphSAGE',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/gnn_pyg/graphSAGE.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/gnn_pyg/graphSAGE.ipynb'
     },
     '3.3_graph_attention_network': {
       label: 'Graph Attention Network',
-      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/main/tutorials/gnn_pyg/graph_attention_network.ipynb'
+      url: 'https://raw.githubusercontent.com/TigerGraph-DevLabs/mlworkbench-docs/0.9/tutorials/gnn_pyg/graph_attention_network.ipynb'
     }
   }
 };
